var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
import { IAxiosAjaxUtilsType, ICryptoUtilsType, } from "@snickerdoodlelabs/common-utils";
import { snickerdoodleSigningDomain, executeMetatransactionTypes, insightDeliveryTypes, insightPreviewTypes, } from "@snickerdoodlelabs/signature-verification";
import { inject, injectable } from "inversify";
import { urlJoin } from "url-join-ts";
let InsightPlatformRepository = class InsightPlatformRepository {
    constructor(cryptoUtils, ajaxUtils) {
        this.cryptoUtils = cryptoUtils;
        this.ajaxUtils = ajaxUtils;
    }
    //
    receivePreviews(consentContractAddress, tokenId, queryCID, signingKey, insightPlatformBaseUrl, answeredQueries) {
        const signableData = {
            consentContractId: consentContractAddress,
            tokenId: tokenId,
            queryCID: queryCID,
            queries: JSON.stringify(answeredQueries),
        };
        return this.cryptoUtils
            .signTypedData(snickerdoodleSigningDomain, insightPreviewTypes, signableData, signingKey)
            .andThen((signature) => {
            const url = new URL(urlJoin(insightPlatformBaseUrl, "/insights/responses/preview"));
            /* Following schema from .yaml file: */
            /* https://github.com/SnickerdoodleLabs/protocol/blob/develop/documentation/openapi/Insight%20Platform%20API.yaml */
            return this.ajaxUtils.post(url, {
                consentContractId: consentContractAddress,
                queryCID: queryCID,
                tokenId: tokenId.toString(),
                queries: answeredQueries,
                signature: signature,
            });
        });
    }
    deliverInsights(consentContractAddress, tokenId, queryCID, returns, rewardParameters, signingKey, insightPlatformBaseUrl) {
        const signableData = {
            consentContractId: consentContractAddress,
            tokenId: tokenId,
            queryCID: queryCID,
            returns: JSON.stringify(returns),
            rewardParameters: JSON.stringify(rewardParameters),
        };
        return this.cryptoUtils
            .signTypedData(snickerdoodleSigningDomain, insightDeliveryTypes, signableData, signingKey)
            .andThen((signature) => {
            const url = new URL(urlJoin(insightPlatformBaseUrl, "insights/responses"));
            return this.ajaxUtils.post(url, {
                consentContractId: consentContractAddress,
                tokenId: tokenId.toString(),
                queryCID: queryCID,
                returns: returns,
                rewardParameters: rewardParameters,
                signature: signature,
            });
        });
    }
    executeMetatransaction(accountAddress, contractAddress, nonce, value, gas, data, metatransactionSignature, signingKey, insightPlatformBaseUrl) {
        const signingData = {
            accountAddress: accountAddress,
            contractAddress: contractAddress,
            nonce: nonce,
            data: data,
            metatransactionSignature: metatransactionSignature,
        };
        return this.cryptoUtils
            .signTypedData(snickerdoodleSigningDomain, executeMetatransactionTypes, signingData, signingKey)
            .andThen((signature) => {
            const url = new URL(urlJoin(insightPlatformBaseUrl, "metatransaction"));
            const postBody = {
                accountAddress: accountAddress,
                contractAddress: contractAddress,
                nonce: nonce,
                value: value,
                gas: gas,
                data: data,
                metatransactionSignature: metatransactionSignature,
                requestSignature: signature,
            };
            return this.ajaxUtils.post(url, postBody);
        })
            .map(() => { });
    }
};
InsightPlatformRepository = __decorate([
    injectable(),
    __param(0, inject(ICryptoUtilsType)),
    __param(1, inject(IAxiosAjaxUtilsType))
], InsightPlatformRepository);
export { InsightPlatformRepository };
//# sourceMappingURL=InsightPlatformRepository.js.map